@@ -22,7 +22,6 @@ void save_cb();
 void save_as_cb();
 void revert_cb();
 void properties_modified_cb();
-void set_group_type_cb();
 void cancel_cb();
 gint delete_event_cb();
 void prop_destroy_cb();
@@ -33,17 +32,18 @@ void remove_view_cb();
 
 gint remove_doc_cb();
 void cleanup_cb();
-void app_created_cb();
 
 void prefs_cb();
-void find_cb();
-void replace_cb();
-void jump_cb();
+void converter_cb();
 void find_next_cb();
 void find_prev_cb();
+void replace_next_cb();
 void replace_one_cb();
 void replace_all_cb();
 void goto_byte_cb();
+void set_find_type_cb();
+void set_replace_type_cb();
+void conv_entry_cb();
 
 void open_selected_file();
 void save_selected_file();
