@@ -14,15 +14,14 @@
 
 #include "hex-document.h"
 #include "gtkhex.h"
-#include "gnome-mdi.h"
 
 #define NO_BUFFER_LABEL "No buffer"
 #define DEFAULT_FONT    "-*-courier-medium-r-normal--12-*-*-*-*-*-*-*"
-#define USE_APP_HELPER  YES_PLEASE_DO
 
-#ifdef USE_APP_HELPER
 extern GnomeUIInfo help_menu[], file_menu[], view_menu[], main_menu[];
-#endif
+
+#define DATA_TYPE_HEX   0
+#define DATA_TYPE_ASCII 1
 
 typedef struct _PropertyUI {
   GnomePropertyBox *pbox;
@@ -31,12 +30,49 @@ typedef struct _PropertyUI {
   GtkButton *font_button;
 } PropertyUI;
 
+typedef struct _JumpDialog {
+  GtkWidget *window;
+  GtkWidget *int_entry;
+  GtkWidget *ok, *cancel;
+} JumpDialog;
+
+typedef struct _ReplaceDialog {
+  GtkWidget *window;
+  GtkWidget *f_string, *r_string;
+  GtkWidget *replace, *replace_all, *next, *close;
+  GtkWidget *type_button[2];
+
+  gint search_type;
+} ReplaceDialog; 
+
+typedef struct _FindDialog {
+  GtkWidget *window;
+  GtkWidget *f_string;
+  GtkWidget *f_next, *f_prev, *f_close;
+  GtkWidget *type_button[2];
+
+  gint search_type;
+} FindDialog;
+
+typedef struct _Converter {
+  GtkWidget *window;
+  GtkWidget *entry[4];
+  GtkWidget *close;
+
+  gulong value;
+} Converter;
+
 extern GnomeMDI *mdi;
 extern gint mdi_mode;
 
 extern GtkWidget *file_sel;
-extern GtkWidget *find_dialog, *replace_dialog, *jump_dialog;
-extern PropertyUI *prefs_ui;
+
+extern FindDialog find_dialog;
+extern ReplaceDialog replace_dialog;
+extern JumpDialog jump_dialog;
+extern Converter converter;
+
+extern PropertyUI prefs_ui;
 
 extern GtkCheckMenuItem *save_config_item;
 
@@ -50,18 +86,16 @@ extern gchar *group_type_label[3];
 extern guint mdi_type[3];
 extern gchar *mdi_type_label[3];
 
-void setup_ui();
+extern guint search_type;
+extern gchar *search_type_label[2];
 
-void redraw_widget(GtkWidget *);
+extern gchar *open_files;
 
-#ifndef USE_APP_HELPER
-GtkMenuBar *create_mdi_menus(GnomeMDI *);
-#endif
-
-void create_find_dialog(GtkWidget **);
-void create_replace_dialog(GtkWidget **);
-void create_jump_dialog(GtkWidget **);
-void create_prefs_dialog(PropertyUI **);
+void create_find_dialog(FindDialog *);
+void create_replace_dialog(ReplaceDialog *);
+void create_jump_dialog(JumpDialog *);
+void create_converter(Converter *);
+void create_prefs_dialog(PropertyUI *);
 
 void show_message(gchar *);
 void report_error(gchar *);
@@ -71,9 +105,6 @@ gint ask_user(GnomeMessageBox *);
 void save_configuration();
 void load_configuration();
 
-/* misc */
-gint compare_data(guchar *, guchar *, gint);
-
 #endif
 
 
