@@ -121,6 +121,8 @@ graph_process_data (Graph *g)
 	 *
 	 */
 
+	bonus = 0; /* keep gcc happy */
+
 	for (draw = 0; draw < 2; draw++) {
 		if (draw) {
 
@@ -175,7 +177,6 @@ graph_process_data (Graph *g)
 			if (draw) {
 				double idx = (double)value / total;
 				gint cb = idx * bonus;
-				gint cb2 = cb >> 1;
 				gint lb, ll1, ll2, le;
 
 				cgh = h * idx;
