@@ -32,7 +32,6 @@
 #define CG (*((gint *)g->data))
 
 static GtkWidget *nLabel;
-static GtkWidget *table;
 static GtkWidget *clist;
 static GtkWidget *clist_menu;
 static GtkWidget *vbox;
@@ -92,8 +91,6 @@ static GtkWidget *xpm_cpu;
 static GtkWidget *xpm_mem;
 static GtkWidget *xpm_swap;
 
-static gint p_pmem;
-static gint p_seconds;
 static gint p_current_time;
 static time_t p_time;
 static float p_elapsed_time;
@@ -154,8 +151,8 @@ static int cmp_ ## NAME (const ProcProcData **P, const ProcProcData **Q) \
 #define SORT_ASC 1
 #define SORT_DSC -1
 
-static sort_field = -1;
-static sort_order = SORT_ASC;
+static int sort_field = -1;
+static int sort_order = SORT_ASC;
 
 CMP_INT (stime)
 CMP_INT (utime)
@@ -282,7 +279,6 @@ procview_user_procs ()
 void
 procview_start_stop (gint start)
 {
-	GtkWidget *p = (!start) ? xpm_stop : xpm_run;
 	/* char **pd = (cfg_run) ? tb_timer_stopped_xpm : tb_timer_xpm; */
 
 	if (!start) {
@@ -631,6 +627,8 @@ renice_cb (GtkWidget *w, gint n)
 
 		rv = setpriority (PRIO_PROCESS, select_pid, nv);
 
+		msg = NULL; /* keep gcc happy */
+
 		if (rv == -1) {
 			switch (errno) {
 			case ESRCH:
@@ -711,7 +709,6 @@ procview_clist_menu_prepare ()
 	GtkWidget *menu;
 	GtkWidget *smenu;
 	GtkWidget *mi;
-	GtkWidget *sep;
 	gint i;
 
 	menu = gtk_menu_new ();
@@ -938,13 +935,13 @@ sprint_fmt (ProcProcData *d, p_fmt fmt)
 			sprintf (tmp, "%d", t->nice);
 			break;
 		case P_RSS:
-			sprintf (tmp, "%d", t->rss << (PAGE_SHIFT - 10));
+			sprintf (tmp, "%ld", t->rss << (PAGE_SHIFT - 10));
 			break;
 		case P_SIZE:
-			sprintf (tmp, "%d", t->size << (PAGE_SHIFT - 10));
+			sprintf (tmp, "%ld", t->size << (PAGE_SHIFT - 10));
 			break;
 		case P_SHARE:
-			sprintf (tmp, "%d", t->share << (PAGE_SHIFT - 10));
+			sprintf (tmp, "%ld", t->share << (PAGE_SHIFT - 10));
 			break;
 		case P_PCPU:
 			sprintf (tmp, "%2d.%1d", d->pcpu / 10, d->pcpu % 10);
@@ -953,7 +950,9 @@ sprint_fmt (ProcProcData *d, p_fmt fmt)
 			sprintf (tmp, "%2d.%1d", d->pmem / 10, d->pmem % 10);
 			break;
 		case P_RESIDENT:
-			sprintf (tmp, "%d", t->resident << (PAGE_SHIFT - 10));
+			sprintf (tmp, "%ld", t->resident << (PAGE_SHIFT - 10));
+			break;
+		default:
 			break;
 		}
 		rv = tmp;
