@@ -2,9 +2,8 @@
 #ifndef __PROCVIEW_H__
 #define __PROCVIEW_H__
 
-#include <gtk/gtk.h>
-
 #include "fromtop.h"
+#include "procbar.h"
 #include "global.h"
 
 typedef enum _p_fmt p_fmt;
@@ -96,6 +95,16 @@ struct _proc_field {
 
 extern proc_field p_fields [];
 
+extern GtkWidget *summary_cpu;
+extern GtkWidget *summary_mem;
+extern GtkWidget *summary_swap;
+
+extern gint cfg_show_summary;
+extern gint cfg_show_summary_cpu;
+extern gint cfg_show_summary_mem;
+extern gint cfg_show_summary_swap;
+extern gint cfg_has_swap;
+
 void *addProcessesView ();
 gchar *sprint_fmt (ProcProcData *d, p_fmt fmt);
         
